.. _introduction:

Introduction
============

The ``dicomweb-client`` build distribution provides client intefaces for DICOMweb RESTful services QIDO-RS, WADO-RS and STOW-RS to search, retrieve and store DICOM objects over the web, respectively. For more information about DICOMweb please refer to the documentation of the `DICOMweb API <http://www.dicomstandard.org/using/dicomweb/>`_ (
`DICOM PS3.18 <http://dicom.nema.org/medical/dicom/current/output/chtml/part18/PS3.18.html>`_).

The :mod:`dicomweb_client` Python package exposes

* Application Programming Interface (API) (see :mod:`api <dicomweb_client.api>` module)
* Command Line Interface (CLI) (see :mod:`cli <dicomweb_client.cli>` module)
